==> celldex_1.4.0.tar.gz: celldex/inst/doc/userguide.R <==
## ---- echo=FALSE, results="hide", message=FALSE-------------------------------
knitr::opts_chunk$set(error=FALSE, message=FALSE, warning=FALSE)
library(BiocStyle)

## -----------------------------------------------------------------------------
library(celldex)
ref <- HumanPrimaryCellAtlasData()

## ----tabulate, echo=FALSE-----------------------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- BlueprintEncodeData()

## ---- echo=FALSE, ref.label="tabulate"----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- MouseRNAseqData()

## ---- echo=FALSE, ref.label="tabulate"----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- ImmGenData()

## ---- echo=FALSE, ref.label="tabulate"----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- DatabaseImmuneCellExpressionData()

## ---- echo=FALSE, ref.label="tabulate"----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- NovershternHematopoieticData()

## ---- echo=FALSE, ref.label="tabulate"----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- MonacoImmuneData()

## ---- echo=FALSE, ref.label="tabulate"----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
sessionInfo()

==> celldex_1.12.0.tar.gz: celldex/inst/doc/userguide.R <==
## ----echo=FALSE, results="hide", message=FALSE--------------------------------
knitr::opts_chunk$set(error=FALSE, message=FALSE, warning=FALSE)
library(BiocStyle)

## -----------------------------------------------------------------------------
library(celldex)
ref <- HumanPrimaryCellAtlasData()

## ----tabulate, echo=FALSE-----------------------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- BlueprintEncodeData()

## ----echo=FALSE, ref.label="tabulate"-----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- MouseRNAseqData()

## ----echo=FALSE, ref.label="tabulate"-----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- ImmGenData()

## ----echo=FALSE, ref.label="tabulate"-----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- DatabaseImmuneCellExpressionData()

## ----echo=FALSE, ref.label="tabulate"-----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- NovershternHematopoieticData()

## ----echo=FALSE, ref.label="tabulate"-----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
ref <- MonacoImmuneData()

## ----echo=FALSE, ref.label="tabulate"-----------------------------------------
samples <- colData(ref)[,c("label.main", "label.fine","label.ont")]
samples <- as.data.frame(samples)
DT::datatable(unique(samples))

## -----------------------------------------------------------------------------
sessionInfo()
